<?php
namespace AustraliaPost\Extensions\Business\API;

use AustraliaPost\Extensions\Business\Helpers\Utilities;

class Address_Validator {

	/**
	 * The single instance of the class.
	 *
	 * @var Address_Validator
	 */
	protected static $_instance = null;

	/**
	 * @return Address_Validator
	 */
	public static function get_instance()
	{
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct()
	{
		add_action( 'woocommerce_after_checkout_validation', [$this, 'validate_suburb'], 10, 2);
	}

	public function validate_suburb( $fields, $errors )
	{
		if (!isset($fields['shipping_country'])) {
			return;
		}

		if ($fields['shipping_country'] !== 'AU') {
			return;
		}

		if (!Utilities::isMyPost()) {
			return;
		}

		$payload = [
			'suburb' => $fields['shipping_city'],
			'state' => $fields['shipping_state'],
			'postcode' => $fields['shipping_postcode'],
		];

		$response = Utilities::get_api_connector()->connect('/address?' . http_build_query($payload), 'GET');

		if (!isset($response['found'])) {
			return;
		}

		if ($response['found'] === true) {
			return;
		}

		$errors->add( 'validation', 'The combination of city, state, and postcode is not correct.' );
	}

}
